package org.elasticsearch.plugin.river.hazelcast

import org.elasticsearch.client.Client
import akka.actor.{Props, Actor}
import org.elasticsearch.common.xcontent.XContentFactory

/** @author Stephen Samuel */
class HazelcastIndexer(index: String, client: Client) extends Actor with Logging {

    def _index(op: IndexOperation) {
        logger.debug(s"Executing index operation [$op]")
        client
          .prepareIndex(index, op.`type`)
          .setSource(XContentFactory
          .jsonBuilder
          .startObject().field("content", op.content).field("timestamp", System.currentTimeMillis()).endObject())
          .execute()
    }

    override def postStop() {
        logger.debug("Indexer actor shutdown")
    }

    def receive = {
        case op: IndexOperation => _index(op)
        case _ =>
    }
}

object HazelcastIndexer {
    def props(index: String, client: Client): Props = Props(new HazelcastIndexer(index, client))
}

case class IndexOperation(`type`: String, content: String)