package org.elasticsearch.plugin.river.hazelcast

import com.hazelcast.core._
import akka.actor.ScalaActorRef

/** @author Stephen Samuel */
class HazelcastQueueConsumer(queue: IQueue[_], indexer: ScalaActorRef) extends Runnable with Logging {

    @volatile var running = true

    def run() {
        while (running) {
            try {
                val e = queue.take()
                logger.trace("Took {} from queue {}", e, queue.getName)
                indexer ! IndexOperation(queue.getName, e.toString)
                if (Thread.interrupted) running = false
            } catch {
                case e: InterruptedException => running = false
            }
        }
    }
}

class HazelcastTopicSubscriber(topic: ITopic[Any], indexer: ScalaActorRef) extends Logging {

    class Listener extends MessageListener[Any] {
        def onMessage(m: Message[Any]) {
            logger.trace("Receieved {} from topic {}", m, topic.getName)
            indexer ! IndexOperation(topic.getName, m.getMessageObject.toString)
        }
    }

    val listener = new Listener
    topic.addMessageListener(listener)

    def shutdown() {
        topic.removeMessageListener(listener)
    }
}


